@@ -8,7 +8,7 @@ from glob import glob
 modname = "conference"
 distname = "cubicweb-%s" % modname
 
-numversion = (0, 19, 0)
+numversion = (0, 20, 0)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
@@ -25,14 +25,14 @@ classifiers = [
 ]
 
 __depends__ = {
-    "cubicweb": ">= 3.29, < 3.38.0",
+    "cubicweb": ">= 3.34, < 3.38.0",
     "cubicweb-addressbook": None,
     "cubicweb-card": ">=1.1.0",
     "cubicweb-comment": None,
     "cubicweb-file": None,
     "cubicweb-tag": None,
     "cubicweb-seo": ">=0.3.0",
-    "rdflib": "<6",
+    "rdflib": ">=6",
 }
 
 # packaging ###
