@@ -83,11 +83,11 @@ class CWUserPrimaryView(primary.PrimaryView):
 
     def render_entity_title(self, entity):
         title = xml_escape(entity.dc_long_title())
-        self.w(u"<h1>%s</h1>" % title)
+        self.w("<h1>%s</h1>" % title)
 
     def render_entity_attributes(self, entity):
         if entity.representing:
-            self.w("%s %s" % (self._cw._(u"Representing"), entity.representing))
+            self.w("%s %s" % (self._cw._("Representing"), entity.representing))
 
 
 class ConferenceTabRewrite(SimpleReqRewriter):
